@@ -2,15 +2,15 @@
 #'
 #' @param index An index name
 #' @param alias An alias name
-#' @param ignore_unavailable (logical) What to do if an specified index name doesn't exist. If set
-#' to TRUE then those indices are ignored.
+#' @param ignore_unavailable (logical) What to do if an specified index name
+#' doesn't exist. If set to \code{TRUE} then those indices are ignored.
 #' @param routing Ignored for now
 #' @param filter Ignored for now
 #' @param ... Curl args passed on to \code{\link[httr]{POST}}
 #' @examples \dontrun{
 #' # Create/update an alias
 #' alias_create(index = "plos", alias = "tables")
-#' 
+#'
 #' # Retrieve a specified alias
 #' alias_get(index="plos")
 #' alias_get(alias="tables")
@@ -51,14 +51,16 @@ aliases_get <- function(index=NULL, alias=NULL, ignore_unavailable=FALSE, ...) {
 #' @export
 #' @rdname alias
 alias_exists <- function(index=NULL, alias=NULL, ...) {
-  res <- HEAD(alias_url(index, alias), ...)
+  #checkconn(...)
+  res <- HEAD(alias_url(index, alias), es_env$headers, make_up(), ...)
   if (res$status_code == 200) TRUE else FALSE
 }
 
 #' @export
 #' @rdname alias
 alias_create <- function(index=NULL, alias, routing=NULL, filter=NULL, ...) {
-  out <- PUT(alias_url(index, alias), c(es_env$headers, make_up(), ...))
+  #checkconn(...)
+  out <- PUT(alias_url(index, alias), es_env$headers, make_up(), ...)
   geterror(out)
   jsonlite::fromJSON(cont_utf8(out), FALSE)
 }
@@ -66,15 +68,16 @@ alias_create <- function(index=NULL, alias, routing=NULL, filter=NULL, ...) {
 #' @export
 #' @rdname alias
 alias_delete <- function(index=NULL, alias, ...) {
-  out <- DELETE(alias_url(index, alias), c(es_env$headers, make_up(), ...))
+  #checkconn(...)
+  out <- DELETE(alias_url(index, alias), es_env$headers, make_up(), ...)
   geterror(out)
   jsonlite::fromJSON(cont_utf8(out), FALSE)
 }
 
 alias_GET <- function(index, alias, ignore, ...) {
-  checkconn()
-  tt <- GET(alias_url(index, alias), 
-             query = ec(list(ignore_unavailable = as_log(ignore))), 
+  #checkconn(...)
+  tt <- GET(alias_url(index, alias),
+             query = ec(list(ignore_unavailable = as_log(ignore))),
              make_up(), es_env$headers, ...)
   geterror(tt)
   jsonlite::fromJSON(cont_utf8(tt), FALSE)
