@@ -6,16 +6,17 @@
 #' @name index
 #'
 #' @param index (character) A character vector of index names
-#' @param features (character) A character vector of features. One or more of settings, mappings,
-#' warmers or aliases
+#' @param features (character) A character vector of features. One or more of 
+#' settings, mappings, or aliases
 #' @param raw If TRUE (default), data is parsed to list. If FALSE, then raw JSON.
 #' @param ... Curl args passed on to \code{\link[httr]{POST}}, \code{\link[httr]{GET}},
 #' \code{\link[httr]{PUT}}, \code{\link[httr]{HEAD}}, or \code{\link[httr]{DELETE}}
 #' @param verbose If TRUE (default) the url call used printed to console.
 #' @param fields (character) Fields to add.
-#' @param metric (character) A character vector of metrics to display. Possible values: "_all",
-#' "completion", "docs", "fielddata", "filter_cache", "flush", "get", "id_cache", "indexing",
-#' "merge", "percolate", "refresh", "search", "segments", "store", "warmer".
+#' @param metric (character) A character vector of metrics to display. Possible 
+#' values: "_all", "completion", "docs", "fielddata", "filter_cache", "flush", 
+#' "get", "id_cache", "indexing", "merge", "percolate", "refresh", "search", 
+#' "segments", "store", "warmer".
 #' @param completion_fields (character) A character vector of fields for completion metric
 #' (supports wildcards)
 #' @param fielddata_fields (character) A character vector of fields for fielddata metric
@@ -89,7 +90,6 @@
 #' index_get(index='shakespeare')
 #' index_get(index='shakespeare', features=c('settings','mappings'))
 #' index_get(index='shakespeare', features='aliases')
-#' index_get(index='shakespeare', features='warmers')
 #'
 #' # check for index existence
 #' index_exists(index='shakespeare')
@@ -147,7 +147,7 @@
 #' index_stats('plos')
 #' index_stats(c('plos','gbif'))
 #' index_stats(c('plos','gbif'), metric='refresh')
-#' index_stats(metric = "indices")
+#' index_stats(metric = "indexing")
 #' index_stats('shakespeare', metric='completion')
 #' index_stats('shakespeare', metric='completion', completion_fields = "completion")
 #' index_stats('shakespeare', metric='fielddata')
@@ -169,24 +169,36 @@
 #' index_recovery("plos", active_only = TRUE)
 #'
 #' # Optimize an index, or many indices
-#' index_optimize('plos')
-#' index_optimize(c('plos','gbif'))
+#' if (gsub("\\.", "", ping()$version$number) < 500) {
+#'   ### ES < v5 - use optimize
+#'   index_optimize('plos')
+#'   index_optimize(c('plos','gbif'))
+#'   index_optimize('plos')
+#' } else {
+#'   ### ES > v5 - use forcemerge
+#'   index_forcemerge('plos')
+#' }
 #'
 #' # Upgrade one or more indices to the latest format. The upgrade process converts any
 #' # segments written with previous formats.
-#' index_upgrade('plos')
-#' index_upgrade(c('plos','gbif'))
+#' if (gsub("\\.", "", ping()$version$number) < 500) {
+#'   index_upgrade('plos')
+#'   index_upgrade(c('plos','gbif'))
+#' }
 #'
-#' # Performs the analysis process on a text and return the tokens breakdown of the text.
+#' # Performs the analysis process on a text and return the tokens breakdown 
+#' # of the text
 #' index_analyze(text = 'this is a test', analyzer='standard')
 #' index_analyze(text = 'this is a test', analyzer='whitespace')
 #' index_analyze(text = 'this is a test', analyzer='stop')
-#' index_analyze(text = 'this is a test', tokenizer='keyword', filters='lowercase')
+#' index_analyze(text = 'this is a test', tokenizer='keyword', 
+#'   filters='lowercase')
 #' index_analyze(text = 'this is a test', tokenizer='keyword', filters='lowercase',
 #'    char_filters='html_strip')
 #' index_analyze(text = 'this is a test', index = 'plos')
 #' index_analyze(text = 'this is a test', index = 'shakespeare')
-#' index_analyze(text = 'this is a test', index = 'shakespeare', config=verbose())
+#' index_analyze(text = 'this is a test', index = 'shakespeare', 
+#'   config=verbose())
 #'
 #' ## NGram tokenizer
 #' body <- '{
@@ -208,11 +220,12 @@
 #'              }
 #'       }
 #' }'
-#' if(index_exists("shakespeare2")) {
+#' if (index_exists("shakespeare2")) {
 #'    index_delete("shakespeare2")
 #' }
 #' tokenizer_set(index = "shakespeare2", body=body)
-#' index_analyze(text = "art thouh", index = "shakespeare2", analyzer='my_ngram_analyzer')
+#' index_analyze(text = "art thouh", index = "shakespeare2", 
+#'   analyzer='my_ngram_analyzer')
 #'
 #' # Explicitly flush one or more indices.
 #' index_flush(index = "plos")
@@ -257,7 +270,6 @@ index_get <- function(index=NULL, features=NULL, raw=FALSE, verbose=TRUE, ...) {
 #' @export
 #' @rdname index
 index_exists <- function(index, ...) {
-  #checkconn(...)
   url <- file.path(make_url(es_get_auth()), esc(index))
   res <- HEAD(url, ..., make_up())
   if (res$status_code == 200) TRUE else FALSE
@@ -266,21 +278,20 @@ index_exists <- function(index, ...) {
 #' @export
 #' @rdname index
 index_delete <- function(index, raw=FALSE, verbose=TRUE, ...) {
-  #checkconn(...)
   url <- paste0(make_url(es_get_auth()), "/", esc(index))
   out <- DELETE(url, make_up(), ...)
   if (verbose) message(URLdecode(out$url))
   geterror(out)
   tt <- structure(cont_utf8(out), class = "index_delete")
-  if (raw) { tt } else { es_parse(tt) }
+  if (raw) tt else es_parse(tt)
 }
 
 #' @export
 #' @rdname index
 index_create <- function(index=NULL, body=NULL, raw=FALSE, verbose=TRUE, ...) {
-  #checkconn(...)
   url <- make_url(es_get_auth())
-  out <- PUT(paste0(url, "/", esc(index)), body = body, make_up(), ...)
+  out <- PUT(paste0(url, "/", esc(index)), body = body, 
+             content_type_json(), make_up(), ...)
   geterror(out)
   if (verbose) message(URLdecode(out$url))
   tt <- cont_utf8(out)
@@ -289,7 +300,9 @@ index_create <- function(index=NULL, body=NULL, raw=FALSE, verbose=TRUE, ...) {
 
 #' @export
 #' @rdname index
-index_recreate <- function(index=NULL, body=NULL, raw=FALSE, verbose=TRUE, ...) {
+index_recreate <- function(index=NULL, body=NULL, raw=FALSE, verbose=TRUE, 
+                           ...) {
+  
   if (index_exists(index, ...)) {
     if (verbose) message("deleting ", index)
     index_delete(index, verbose = verbose, ...)
@@ -312,13 +325,20 @@ index_open <- function(index, ...) {
 
 #' @export
 #' @rdname index
-index_stats <- function(index=NULL, metric=NULL, completion_fields=NULL, fielddata_fields=NULL,
-  fields=NULL, groups=NULL, level='indices', ...) {
+index_stats <- function(index=NULL, metric=NULL, completion_fields=NULL, 
+                        fielddata_fields=NULL, fields=NULL, groups=NULL, 
+                        level='indices', ...) {
+  
   url <- make_url(es_get_auth())
-  url <- if (is.null(index)) file.path(url, "_stats") else file.path(url, esc(cl(index)), "_stats")
+  url <- if (is.null(index)) {
+    file.path(url, "_stats") 
+  } else {
+    file.path(url, esc(cl(index)), "_stats")
+  }
   url <- if (!is.null(metric)) file.path(url, cl(metric)) else url
-  args <- ec(list(completion_fields=completion_fields, fielddata_fields=fielddata_fields,
-                  fields=fields, groups=groups, level=level))
+  args <- ec(list(completion_fields = completion_fields, 
+                  fielddata_fields = fielddata_fields,
+                  fields = fields, groups = groups, level = level))
   es_GET_(url, args, ...)
 }
 
@@ -326,16 +346,23 @@ index_stats <- function(index=NULL, metric=NULL, completion_fields=NULL, fieldda
 #' @rdname index
 index_settings <- function(index="_all", ...) {
   url <- make_url(es_get_auth())
-  url <- if(is.null(index) || index == "_all") file.path(url, "_settings") else file.path(url, esc(cl(index)), "_settings")
+  url <- if (is.null(index) || index == "_all") {
+    file.path(url, "_settings")
+  } else {
+    file.path(url, esc(cl(index)), "_settings")
+  }
   es_GET_(url, ...)
 }
 
 #' @export
 #' @rdname index
 index_settings_update <- function(index=NULL, body, ...) {
-  #checkconn(...)
   url <- make_url(es_get_auth())
-  url <- if (is.null(index)) file.path(url, "_settings") else file.path(url, esc(cl(index)), "_settings")
+  url <- if (is.null(index)) {
+    file.path(url, "_settings") 
+  } else {
+    file.path(url, esc(cl(index)), "_settings")
+  }
   body <- check_inputs(body)
   tt <- PUT(url, make_up(), ..., body = body)
   geterror(tt)
@@ -345,20 +372,30 @@ index_settings_update <- function(index=NULL, body, ...) {
 
 #' @export
 #' @rdname index
-index_segments <- function(index = NULL, ...) es_GET_wrap1(index, "_segments", ...)
+index_segments <- function(index = NULL, ...) {
+  es_GET_wrap1(index, "_segments", ...)
+}
 
 #' @export
 #' @rdname index
-index_recovery <- function(index = NULL, detailed = FALSE, active_only = FALSE, ...){
+index_recovery <- function(index = NULL, detailed = FALSE, active_only = FALSE, 
+                           ...) {
+  
   stop_es_version(110, "index_recovery")
-  args <- ec(list(detailed = as_log(detailed), active_only = as_log(active_only)))
+  args <- ec(list(detailed = as_log(detailed), 
+                  active_only = as_log(active_only)))
   es_GET_wrap1(index, "_recovery", args, ...)
 }
 
 #' @export
 #' @rdname index
-index_optimize <- function(index = NULL, max_num_segments = NULL, only_expunge_deletes = FALSE,
+index_optimize <- function(index = NULL, max_num_segments = NULL, 
+  only_expunge_deletes = FALSE,
   flush = TRUE, wait_for_merge = TRUE, ...) {
+  
+  if (es_ver() >= 500) {
+    stop("optimize is gone in ES >= v5, see ?index_forcemerge")
+  }
   args <- ec(list(max_num_segments = max_num_segments,
                   only_expunge_deletes = as_log(only_expunge_deletes),
                   flush = as_log(flush),
@@ -367,59 +404,96 @@ index_optimize <- function(index = NULL, max_num_segments = NULL, only_expunge_d
   es_POST_(index, which = "_optimize", args, ...)
 }
 
+#' @export
+#' @rdname index
+index_forcemerge <- function(index = NULL, max_num_segments = NULL, 
+                           only_expunge_deletes = FALSE, flush = TRUE, ...) {
+  
+  if (es_ver() < 500) {
+    stop("forcemerge is only in ES >= v5, see ?index_optimize")
+  }
+  args <- ec(list(
+    max_num_segments = max_num_segments,
+    only_expunge_deletes = as_log(only_expunge_deletes),
+    flush = as_log(flush)
+  ))
+  es_POST_(index, which = "_forcemerge", args, ...)
+}
+
 #' @export
 #' @rdname index
 index_upgrade <- function(index = NULL, wait_for_completion = FALSE, ...) {
   stop_es_version(120, "index_get")
+  if (es_ver() >= 500) {
+    stop("upgrade is removed in ES >= v5, see
+https://www.elastic.co/guide/en/elasticsearch/reference/current/reindex-upgrade.html")
+  }
   args <- ec(list(wait_for_completion = as_log(wait_for_completion)))
   es_POST_(index, "_upgrade", args, ...)
 }
 
 #' @export
 #' @rdname index
-index_analyze <- function(text=NULL, field=NULL, index=NULL, analyzer=NULL, tokenizer=NULL,
-                          filters=NULL, char_filters=NULL, body=list(), ...) {
+index_analyze <- function(text=NULL, field=NULL, index=NULL, analyzer=NULL, 
+                          tokenizer=NULL, filters=NULL, char_filters=NULL, 
+                          body=list(), ...) {
   url <- make_url(es_get_auth())
   if (!is.null(index)) {
     url <- sprintf("%s/%s/_analyze", url, esc(cl(index)))
   } else {
     url <- sprintf("%s/_analyze", url)
   }
-  args <- ec(list(text=text, analyzer=analyzer, tokenizer=tokenizer, filters=filters,
-                  char_filters=char_filters, field=field))
+  
+  if (es_ver() >= 500) {
+    body <- ec(list(text = text, analyzer = analyzer, tokenizer = tokenizer, 
+                 filter = list(filters), char_filter = char_filters, 
+                 field = field))
+    args <- list()
+  } else {
+    body <- list()
+    args <- ec(list(text = text, analyzer = analyzer, tokenizer = tokenizer, 
+                    filters = filters, char_filters = char_filters, 
+                    field = field))
+  }
+  
   analyze_POST(url, args, body, ...)$tokens
 }
 
 #' @export
 #' @rdname index
-index_flush <- function(index=NULL, force=FALSE, full=FALSE, wait_if_ongoing=FALSE, ...) {
+index_flush <- function(index=NULL, force=FALSE, full=FALSE, 
+                        wait_if_ongoing=FALSE, ...) {
+  
   url <- make_url(es_get_auth())
   if (!is.null(index)) {
     url <- sprintf("%s/%s/_flush", url, esc(cl(index)))
   } else {
     url <- sprintf("%s/_flush", url)
   }
-  args <- ec(list(force=as_log(force), full=as_log(full), wait_if_ongoing=as_log(wait_if_ongoing)))
+  args <- ec(list(force = as_log(force), full = as_log(full), 
+                  wait_if_ongoing = as_log(wait_if_ongoing)))
   cc_POST(url, args, ...)
 }
 
 #' @export
 #' @rdname index
-index_clear_cache <- function(index=NULL, filter=FALSE, filter_keys=NULL, fielddata=FALSE,
-                              query_cache=FALSE, id_cache=FALSE, ...) {
+index_clear_cache <- function(index=NULL, filter=FALSE, filter_keys=NULL, 
+                              fielddata=FALSE, query_cache=FALSE, 
+                              id_cache=FALSE, ...) {
   url <- make_url(es_get_auth())
   if (!is.null(index)) {
     url <- sprintf("%s/%s/_cache/clear", url, esc(cl(index)))
   } else {
     url <- sprintf("%s/_cache/clear", url)
   }
-  args <- ec(list(filter=as_log(filter), filter_keys=filter_keys, fielddata=as_log(fielddata),
-                  query_cache=as_log(query_cache), id_cache=as_log(id_cache)))
+  args <- ec(list(filter = as_log(filter), filter_keys = filter_keys, 
+                  fielddata = as_log(fielddata), 
+                  query_cache = as_log(query_cache), 
+                  id_cache = as_log(id_cache)))
   cc_POST(url, args, ...)
 }
 
 close_open <- function(index, which, ...){
-  #checkconn(...)
   url <- make_url(es_get_auth())
   url <- sprintf("%s/%s/%s", url, esc(index), which)
   out <- POST(url, make_up(), ...)
@@ -429,21 +503,27 @@ close_open <- function(index, which, ...){
 
 es_GET_wrap1 <- function(index, which, args=NULL, ...){
   url <- make_url(es_get_auth())
-  url <- if (is.null(index)) file.path(url, which) else file.path(url, esc(cl(index)), which)
+  url <- if (is.null(index)) {
+    file.path(url, which) 
+  } else {
+    file.path(url, esc(cl(index)), which)
+  }
   es_GET_(url, args, ...)
 }
 
 es_POST_ <- function(index, which, args=NULL, ...){
-  #checkconn(...)
   url <- make_url(es_get_auth())
-  url <- if (is.null(index)) file.path(url, which) else file.path(url, esc(cl(index)), which)
+  url <- if (is.null(index)) {
+    file.path(url, which) 
+  } else {
+    file.path(url, esc(cl(index)), which)
+  }
   tt <- POST(url, query = args, make_up(), es_env$headers, ...)
   geterror(tt)
   jsonlite::fromJSON(cont_utf8(tt), FALSE)
 }
 
 analyze_GET <- function(url, args = NULL, ...){
-  #checkconn(...)
   out <- GET(url, query = args, make_up(), es_env$headers, ...)
   stop_for_status(out)
   tt <- cont_utf8(out)
@@ -451,16 +531,15 @@ analyze_GET <- function(url, args = NULL, ...){
 }
 
 analyze_POST <- function(url, args = NULL, body, ...){
-  #checkconn(...)
   body <- check_inputs(body)
-  out <- POST(url, query = args, body = body, make_up(), es_env$headers, ...)
-  stop_for_status(out)
+  out <- POST(url, query = args, body = body, make_up(),
+              content_type_json(), es_env$headers, ...)
+  geterror(out)
   tt <- cont_utf8(out)
   jsonlite::fromJSON(tt)
 }
 
 cc_POST <- function(url, args = NULL, ...){
-  #checkconn(...)
   tt <- POST(url, body = args, encode = "json", make_up(), es_env$headers, ...)
   if (tt$status_code > 202) geterror(tt)
   res <- cont_utf8(tt)
