@@ -5,12 +5,13 @@
 #' @export
 #' @param x (character) A file path
 #' @param raw (logical) Get raw JSON back or not.
-#' @param asdf (logical) If \code{TRUE}, use \code{\link[jsonlite]{fromJSON}} to parse JSON
-#' directly to a data.frame. If \code{FALSE} (Default), list output is given.
+#' @param asdf (logical) If \code{TRUE}, use \code{\link[jsonlite]{fromJSON}} 
+#' to parse JSON directly to a data.frame. If \code{FALSE} (Default), list 
+#' output is given.
 #' @param ... Curl args passed on to \code{\link[httr]{POST}}
 #'
-#' @details This function behaves similarly to \code{\link{docs_bulk}} - performs
-#' searches based on queries defined in a file.
+#' @details This function behaves similarly to \code{\link{docs_bulk}} - 
+#' performs searches based on queries defined in a file.
 #' @seealso \code{\link{Search_uri}} \code{\link{Search}}
 #' @examples \dontrun{
 #' connect()
@@ -24,10 +25,10 @@
 #' msearch("~/mysearch.json")
 #' }
 msearch <- function(x, raw = FALSE, asdf = FALSE, ...) {
-  #checkconn(...)
   if (!file.exists(x)) stop("file ", x, " does not exist", call. = FALSE)
   url <- paste0(make_url(es_get_auth()), '/_msearch')
-  tt <- POST(url, make_up(), es_env$headers, ..., body = upload_file(x, type = "application/json"), encode = "json")
+  tt <- POST(url, make_up(), es_env$headers, ..., 
+             body = upload_file(x, type = "application/json"), encode = "json")
   geterror(tt)
   res <- cont_utf8(tt)
   if (raw) res else jsonlite::fromJSON(res, asdf)
